[Libreoffice-commits] core.git: oox/source

Gabor Kelemen (via logerrit) logerrit at kemper.freedesktop.org
Mon Jul 15 07:59:05 UTC 2019


 oox/source/helper/graphichelper.cxx |    4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

New commits:
commit 184a4771dad448a37f80b29bc62ad62e0a6a4bb6
Author:     Gabor Kelemen <kelemen.gabor2 at nisz.hu>
AuthorDate: Sun Jul 14 20:21:08 2019 +0200
Commit:     Miklos Vajna <vmiklos at collabora.com>
CommitDate: Mon Jul 15 09:58:07 2019 +0200

    tdf#126310 Disable lazy loading of WMF images
    
    Change-Id: I70d271e29bedc640cbfeab187ddb9ffce3e779e6
    Reviewed-on: https://gerrit.libreoffice.org/75599
    Tested-by: Jenkins
    Reviewed-by: Miklos Vajna <vmiklos at collabora.com>

diff --git a/oox/source/helper/graphichelper.cxx b/oox/source/helper/graphichelper.cxx
index 6ada6cd5a5a0..8e56f58ccabb 100644
--- a/oox/source/helper/graphichelper.cxx
+++ b/oox/source/helper/graphichelper.cxx
@@ -355,9 +355,9 @@ Reference< XGraphic > GraphicHelper::importEmbeddedGraphic( const OUString& rStr
         EmbeddedGraphicMap::const_iterator aIt = maEmbeddedGraphics.find( rStreamName );
         if( aIt == maEmbeddedGraphics.end() )
         {
             // Lazy-loading doesn't work with TIFF at the moment.
             WmfExternal aHeader;
-            if (rStreamName.endsWith(".tiff") && !pExtHeader)
+            if ( (rStreamName.endsWith(".tiff") || rStreamName.endsWith(".wmf") ) && !pExtHeader)
                 pExtHeader = &aHeader;
 
             xGraphic = importGraphic(mxStorage->openInputStream(rStreamName), pExtHeader);
@@ -355,9 +355,9 @@ Reference< XGraphic > GraphicHelper::importEmbeddedGraphic( const OUString& rStr
         if( aIt == maEmbeddedGraphics.end() )
         {
-            // Lazy-loading doesn't work with TIFF at the moment.
+            // Lazy-loading doesn't work with TIFF or WMF at the moment.
             WmfExternal aHeader;


More information about the Libreoffice-commits mailing list